@@ -20,17 +20,22 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from typing import Any
+from typing import Optional, Tuple, Type
+import midb
 from midb.persistent_objects import PersistentSequence
 
 
 class PTuple(PersistentSequence):
+    """ A persistent version of the built-in tuple type. """
+    _backend: Optional["midb.backend.SQLiteBackend"]
+    _id: Optional[int]
+    _temp: Optional[Tuple]
 
     @property
-    def _equivalent_builtin_class(self):
+    def _equivalent_builtin_class(self) -> Type:
         """ return tuple, the built-in class that PTuple is emulating """
         return tuple
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         """ implement: hash(self) """
         return hash(self.in_memory())
\ No newline at end of file
